﻿// Random Checkers (v2)
//
// Jim Bumgardner

SW = Stage.width;
SH = Stage.height;

COLUMNS = 21;
ROWS = 21;
TILE_X = SW/COLUMNS;
TILE_Y = SW/ROWS;
LASTCOLUMN = COLUMNS - 1;
LASTROW = ROWS - 1;
PIXELS_PER_PASS = 12;	// number of pixels to color each pass
DEG_120 = 120*Math.PI/180;
DEG_240 = 240*Math.PI/180;

hasSymmetry = false;
hasCheckers = false;
saturation = .5;
px = py = 0;
doScroll = false;
isRandom = true;

MovieClip.prototype.drawPixel = function()
{
	this.clear();
	this.moveTo(0,0);
	this.beginFill(0);
	this.lineTo(0+TILE_X,0);
	this.lineTo(0+TILE_X,0+TILE_Y);
	this.lineTo(0,0+TILE_Y);
	this.lineTo(0,0);
	this.endFill();
}

function randomPix()
{
	for (var i = 0; i < PIXELS_PER_PASS; ++i) 
	{
		// additional code to produce checkboard pattern in colors
		var t = getTimer()*.001;
		var r = 128+Math.sin(t)*127;
		var g = 128+Math.sin(t + DEG_120*saturation)*127;
		var b = 128+Math.sin(t + DEG_240*saturation)*127;
		var tint = (r << 16) | (g << 8) | b;

		if (hasCheckers) 
		{
			var hilo = ((px + py) & 1);		// this produces a checkerboard pattern...
			if (hilo)
				tint |= 0x808080;
			else
				tint &= 0x7F7F7F;
		}
	
		this["pix_" + px + "_" + py].itsColor.setRGB(tint);
		if (hasSymmetry) {
			this["pix_" + (LASTCOLUMN-px) + "_" + py].itsColor.setRGB(tint);
			this["pix_" + (LASTCOLUMN-px) + "_" + (LASTROW-py)].itsColor.setRGB(tint);
			this["pix_" + px + "_" + (LASTROW-py)].itsColor.setRGB(tint);
		
		}
		if (isRandom)
		{
			px = Math.floor(Math.random()*COLUMNS);
			py = Math.floor(Math.random()*ROWS);
		}
		else
		{
			if (++px > LASTCOLUMN) {
				px = 0;
				if (++py > LASTROW) {
					py = 0;
				}
			}
		}
	}
	if (doScroll) {
		for (var i = 0; i < COLUMNS; ++i) {
			for (var j = 0; j < ROWS; ++j) {
				var mc = this["pix_" + i + "_" + j];
				mc._y = (mc._y + SW-TILE_Y) % (SW);
			}
		}
	}
}

var n = 0;
for (var i = 0; i < COLUMNS; ++i) {
	for (var j = 0; j < ROWS; ++j) {
		var h = this.createEmptyMovieClip("pix_" + i + "_" + j, n++);
		h._x = i * TILE_X;
		h._y = j * TILE_Y;
		h.drawPixel();
		h.itsColor = new Color(h);
	}
}
this.onEnterFrame = randomPix;

// User Interface Stuff
#include "jbumUI.as"
button_sym.setupToggleButton("symmetry", hasSymmetry, function(t) { hasSymmetry = t; },true);
button_checkers.setupToggleButton("checkers", hasCheckers, function(t) { hasCheckers = t;  },true);
button_scroll.setupToggleButton("scroll", doScroll, function(t) { doScroll = t; },true);
button_random.setupToggleButton("random", isRandom, function(t) { isRandom = t; },true);
colorslider_mc.setupSlider('saturation',0,1, saturation,function(t) { saturation = t;  } );
